@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 from __future__ import with_statement
 import py
 import pytest
@@ -102,12 +104,9 @@ class TestLocalPath(common.CommonFSTests):
         assert old == py.path.local()
 
     def test_initialize_reldir(self, path1):
-        old = path1.chdir()
-        try:
+        with path1.as_cwd():
             p = local('samplefile')
             assert p.check()
-        finally:
-            old.chdir()
 
     @pytest.mark.xfail("sys.version_info < (2,6) and sys.platform == 'win32'")
     def test_tilde_expansion(self):
@@ -123,6 +122,9 @@ class TestLocalPath(common.CommonFSTests):
         assert path3 != path2
         assert path2 != path3
 
+    def test_eq_with_none(self, path1):
+        assert path1 != None
+
     def test_gt_with_strings(self, path1):
         path2 = path1.join('sampledir')
         path3 = str(path1.join("ttt"))
@@ -293,6 +295,14 @@ class TestLocalPath(common.CommonFSTests):
 class TestExecutionOnWindows:
     pytestmark = win32only
 
+    def test_sysfind_bat_exe_before(self, tmpdir, monkeypatch):
+        monkeypatch.setenv("PATH", str(tmpdir), prepend=os.pathsep)
+        tmpdir.ensure("hello")
+        h = tmpdir.ensure("hello.bat")
+        x = py.path.local.sysfind("hello")
+        assert x == h
+
+
 class TestExecution:
     pytestmark = skiponwin32
 
@@ -510,11 +520,8 @@ def test_samefile(tmpdir):
     assert tmpdir.samefile(tmpdir)
     p = tmpdir.ensure("hello")
     assert p.samefile(p)
-    old = p.dirpath().chdir()
-    try:
+    with p.dirpath().as_cwd():
         assert p.samefile(p.basename)
-    finally:
-        old.chdir()
     if sys.platform == "win32":
         p1 = p.__class__(str(p).lower())
         p2 = p.__class__(str(p).upper())
@@ -570,12 +577,9 @@ class TestWINLocalPath:
     def test_sysfind_in_currentdir(self, path1):
         cmd = py.path.local.sysfind('cmd')
         root = cmd.new(dirname='', basename='') # c:\ in most installations
-        old = root.chdir()
-        try:
+        with root.as_cwd():
             x = py.path.local.sysfind(cmd.relto(root))
             assert x.check(file=1)
-        finally:
-            old.chdir()
 
 class TestPOSIXLocalPath:
     pytestmark = skiponwin32
@@ -774,3 +778,26 @@ class TestPOSIXLocalPath:
         group = path1.stat().group
         path1.chown(owner, group)
 
+
+class TestUnicodePy2Py3:
+    def test_join_ensure(self, tmpdir):
+        x = py.path.local(tmpdir.strpath)
+        part = py.builtin._totext("hällo", "utf8")
+        y = x.ensure(part)
+        assert x.join(part) == y
+
+    def test_listdir(self, tmpdir):
+        x = py.path.local(tmpdir.strpath)
+        part = py.builtin._totext("hällo", "utf8")
+        y = x.ensure(part)
+        assert x.listdir(part)[0] == y
+
+    @pytest.mark.xfail(reason="changing read/write might break existing usages")
+    def test_read_write(self, tmpdir):
+        x = tmpdir.join("hello")
+        part = py.builtin._totext("hällo", "utf8")
+        x.write(part)
+        assert x.read() == part
+        x.write(part.encode(sys.getdefaultencoding()))
+        assert x.read() == part.encode(sys.getdefaultencoding())
+
